@@ -8,6 +8,7 @@
 #include <QDebug>
 #include <QModelIndex>
 #include <QProcess>
+#include <QQmlEngine>
 #include <QQuickWindow>
 
 #include <KApplicationTrader>
@@ -18,18 +19,38 @@
 #include <KSharedConfig>
 #include <KSycoca>
 
+#include <chrono>
+
+using namespace std::chrono_literals;
+
 ApplicationListModel::ApplicationListModel(QObject *parent)
     : QAbstractListModel(parent)
+    , m_reloadAppsTimer{new QTimer{this}}
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(KSycoca::self(), qOverload<const QStringList &>(&KSycoca::databaseChanged), this, &ApplicationListModel::sycocaDbChanged);
-#else
-    connect(KSycoca::self(), &KSycoca::databaseChanged, this, &ApplicationListModel::sycocaDbChanged);
-#endif
+    m_reloadAppsTimer->setSingleShot(true);
+    m_reloadAppsTimer->setInterval(100ms);
+    connect(m_reloadAppsTimer, &QTimer::timeout, this, &ApplicationListModel::sycocaDbChanged);
+
+    connect(KSycoca::self(), &KSycoca::databaseChanged, m_reloadAppsTimer, static_cast<void (QTimer::*)()>(&QTimer::start));
 }
 
 ApplicationListModel::~ApplicationListModel() = default;
 
+ApplicationListModel *ApplicationListModel::self()
+{
+    static ApplicationListModel *inst = new ApplicationListModel(nullptr);
+    return inst;
+}
+
+ApplicationListModel *ApplicationListModel::create(QQmlEngine *qmlEngine, QJSEngine *jsEngine)
+{
+    Q_UNUSED(qmlEngine);
+    Q_UNUSED(jsEngine);
+    auto *model = self();
+    QQmlEngine::setObjectOwnership(model, QQmlEngine::CppOwnership);
+    return model;
+}
+
 QHash<int, QByteArray> ApplicationListModel::roleNames() const
 {
     return {{ApplicationRole, QByteArrayLiteral("application")}};
@@ -47,12 +68,6 @@ void ApplicationListModel::loadApplications()
 
     const QStringList blacklist = blgroup.readEntry("blacklist", QStringList());
 
-    beginResetModel();
-
-    m_applicationList.clear();
-
-    QList<Application *> unorderedList;
-
     auto filter = [blacklist](const KService::Ptr &service) -> bool {
         if (service->noDisplay()) {
             return false;
@@ -69,6 +84,12 @@ void ApplicationListModel::loadApplications()
         return true;
     };
 
+    beginResetModel();
+
+    m_applicationList.clear();
+
+    QList<Application *> unorderedList;
+
     const KService::List apps = KApplicationTrader::query(filter);
 
     for (const KService::Ptr &service : apps) {
@@ -87,6 +108,7 @@ void ApplicationListModel::loadApplications()
 
 QVariant ApplicationListModel::data(const QModelIndex &index, int role) const
 {
+    Q_UNUSED(role)
     if (!index.isValid()) {
         return QVariant();
     }
