@@ -11,6 +11,12 @@
 #include <QObject>
 #include <QQuickItem>
 #include <QSet>
+#include <QTimer>
+
+#include <qqmlregistration.h>
+
+class QJSEngine;
+class QQmlEngine;
 
 /**
  * @short The base application list, used directly by the full app list page.
@@ -18,12 +24,18 @@
 class ApplicationListModel : public QAbstractListModel
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
 public:
-    enum Roles { ApplicationRole = Qt::UserRole + 1 };
+    enum Roles {
+        ApplicationRole = Qt::UserRole + 1
+    };
 
     ApplicationListModel(QObject *parent = nullptr);
     ~ApplicationListModel() override;
+    static ApplicationListModel *self();
+    static ApplicationListModel *create(QQmlEngine *qmlEngine, QJSEngine *jsEngine);
 
     int rowCount(const QModelIndex &parent = QModelIndex()) const override;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
@@ -34,9 +46,7 @@ public:
 public Q_SLOTS:
     void sycocaDbChanged();
 
-Q_SIGNALS:
-    void launchError(const QString &msg);
-
 protected:
     QList<Application *> m_applicationList;
+    QTimer *m_reloadAppsTimer{nullptr};
 };
