@@ -9,14 +9,26 @@
 #include <QDebug>
 #include <QQuickItem>
 
+K_PLUGIN_CLASS_WITH_JSON(HomeScreen, "metadata.json")
+
 HomeScreen::HomeScreen(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Containment{parent, data, args}
+    , m_settings{new HalcyonSettings{this, this}}
+    , m_pinnedModel{new PinnedModel{m_settings, this}}
 {
     setHasConfigurationInterface(true);
 }
 
 HomeScreen::~HomeScreen() = default;
 
-K_PLUGIN_CLASS(HomeScreen)
+HalcyonSettings *HomeScreen::settings() const
+{
+    return m_settings;
+}
+
+PinnedModel *HomeScreen::pinnedModel() const
+{
+    return m_pinnedModel;
+}
 
 #include "homescreen.moc"
