@@ -11,6 +11,8 @@
 #include <QDebug>
 #include <QGuiApplication>
 
+K_PLUGIN_CLASS_WITH_JSON(TaskPanel, "metadata.json")
+
 // register type for Keyboards.KWinVirtualKeyboard.forceActivate();
 Q_DECLARE_METATYPE(QDBusPendingReply<>)
 
@@ -29,6 +31,4 @@ void TaskPanel::triggerTaskSwitcher() const
     QDBusConnection::sessionBus().send(message);
 }
 
-K_PLUGIN_CLASS(TaskPanel)
-
 #include "taskpanel.moc"
